==> packageinstaller-pkglist_0.3.30.tar.xz: packageinstaller-pkglist/cups.pm <==
<?xml version="1.0"?>
<app>

<category>
Printing
</category>

<name>
CUPS
</name>

<description>
   <am>CUPS Printing system</am>
   <ar>CUPS Printing system</ar>
   <be>CUPS Printing system</be>
   <bg>CUPS Printing system</bg>
   <bn>CUPS Printing system</bn>
   <ca>CUPS Printing system</ca>
   <cs>CUPS Printing system</cs>
   <da>CUPS Printing system</da>
   <de>CUPS Drucksystemsoftware</de>
   <el>Σύστημα εκτύπωσης CUPS</el>
   <en>CUPS Printing system</en>
   <es_ES>CUPS Printing system</es_ES>
   <es>Sistema CUPS para impresión</es>
   <et>CUPS Printing system</et>
   <eu>CUPS Printing system</eu>
   <fa>CUPS Printing system</fa>
   <fil_PH>CUPS Printing system</fil_PH>
   <fi>CUPS Printing system</fi>
   <fr_BE>CUPS Système d'impression</fr_BE>
   <fr>CUPS Système d'impression</fr>
   <gl_ES>CUPS Printing system</gl_ES>
   <he_IL>CUPS Printing system</he_IL>
   <hi>CUPS Printing system</hi>
   <hr>CUPS Printing system</hr>
   <hu>CUPS Printing system</hu>
   <id>CUPS Printing system</id>
   <is>CUPS Printing system</is>
   <it>CUPS Printing system</it>
   <ja>CUPS 印刷システム</ja>
   <kk>CUPS Printing system</kk>
   <ko>CUPS Printing system</ko>
   <lt>CUPS Printing system</lt>
   <mk>CUPS Printing system</mk>
   <mr>CUPS Printing system</mr>
   <nb_NO>CUPS Printing system</nb_NO>
   <nb>CUPS utskriftssystem</nb>
   <nl_BE>CUPS Printing system</nl_BE>
   <nl>CUPS Printing system</nl>
   <pl>CUPS Printing system</pl>
   <pt_BR>Sistema de Impressão CUPS</pt_BR>
   <pt>Sistema de impressão CUPS (Common Unix Printing System)</pt>
   <ro>CUPS Printing system</ro>
   <ru>CUPS Printing system</ru>
   <sk>CUPS Printing system</sk>
   <sl>CUPS Printing system</sl>
   <sq>CUPS Printing system</sq>
   <sr>CUPS Printing system</sr>
   <sv>CUPS Skrivarsystem</sv>
   <th>CUPS Printing system</th>
   <tr>CUPS Printing system</tr>
   <uk>CUPS Printing system</uk>
   <vi>CUPS Printing system</vi>
   <zh_CN>CUPS Printing system</zh_CN>
   <zh_HK>CUPS Printing system</zh_HK>
   <zh_TW>CUPS Printing system</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
cups
cups-filters
cups-pdf
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
cups
cups-filters
cups-pdf
</uninstall_package_names>
</app>

==> packageinstaller-pkglist_0.3.32.tar.xz: packageinstaller-pkglist/cups.pm <==
<?xml version="1.0"?>
<app>

<category>
Printing
</category>

<name>
CUPS
</name>

<description>
   <am>CUPS Printing system</am>
   <ar>CUPS Printing system</ar>
   <be>CUPS Printing system</be>
   <bg>CUPS Printing system</bg>
   <bn>CUPS Printing system</bn>
   <ca>CUPS Printing system</ca>
   <cs>CUPS Printing system</cs>
   <da>CUPS Printing system</da>
   <de>CUPS Drucksystemsoftware</de>
   <el>Σύστημα εκτύπωσης CUPS</el>
   <en>CUPS Printing system</en>
   <es_ES>Sistema CUPS para impresión</es_ES>
   <es>Sistema CUPS para impresión</es>
   <et>CUPS Printing system</et>
   <eu>CUPS Printing system</eu>
   <fa>CUPS Printing system</fa>
   <fil_PH>CUPS Printing system</fil_PH>
   <fi>CUPS Printing system</fi>
   <fr_BE>CUPS Printing system</fr_BE>
   <fr>CUPS Système d'impression</fr>
   <gl_ES>CUPS Printing system</gl_ES>
   <gu>CUPS Printing system</gu>
   <he_IL>CUPS Printing system</he_IL>
   <hi>CUPS Printing system</hi>
   <hr>CUPS Printing system</hr>
   <hu>CUPS Printing system</hu>
   <id>CUPS Printing system</id>
   <is>CUPS Printing system</is>
   <it>CUPS sistema di stampa</it>
   <ja>CUPS 印刷システム</ja>
   <kk>CUPS Printing system</kk>
   <ko>CUPS Printing system</ko>
   <lt>CUPS Printing system</lt>
   <mk>CUPS Printing system</mk>
   <mr>CUPS Printing system</mr>
   <nb_NO>CUPS Printing system</nb_NO>
   <nb>CUPS utskriftssystem</nb>
   <nl_BE>CUPS Printing system</nl_BE>
   <nl>CUPS Printing system</nl>
   <pl>CUPS Printing system</pl>
   <pt_BR>Sistema de Impressão CUPS</pt_BR>
   <pt>Sistema de impressão CUPS (Common Unix Printing System)</pt>
   <ro>CUPS Printing system</ro>
   <ru>CUPS Printing system</ru>
   <sk>CUPS Printing system</sk>
   <sl>CUPS sistem za tiskanje</sl>
   <sq>CUPS Printing system</sq>
   <sr>CUPS Printing system</sr>
   <sv>CUPS Skrivarsystem</sv>
   <th>CUPS Printing system</th>
   <tr>CUPS Yazdırma sistemi</tr>
   <uk>CUPS Printing system</uk>
   <vi>CUPS Printing system</vi>
   <zh_CN>CUPS Printing system</zh_CN>
   <zh_HK>CUPS Printing system</zh_HK>
   <zh_TW>CUPS Printing system</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
cups
cups-filters
cups-pdf
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
cups
cups-filters
cups-pdf
</uninstall_package_names>
</app>
